<?php

/**
 * Fired during plugin activation
 *
 * @link       https://devrohit.com/
 * @since      1.2.2
 *
 * @package    Dr_Affilate
 * @subpackage Dr_Affilate/includes
 */

/**
 * Fired during plugin activation.
 *
 * This class defines all code necessary to run during the plugin's activation.
 *
 * @since      1.2.2
 * @package    Dr_Affilate
 * @subpackage Dr_Affilate/includes
 * @author     Rohit Urane <rohiturane50@gmail.com>
 */
class Dr_Affilate_Activator {

	/**
	 * After activating plugin run this function
	 *
	 * Long Description.
	 *
	 * @since    1.2.2
	 */
	public static function activate() {
		global $wpdb;
		require_once( ABSPATH .'wp-admin/includes/upgrade.php' );

		$table_name = $wpdb->prefix . "dr_affiliate"; 
		$charset_collate = $wpdb->get_charset_collate();
		$sql = "CREATE TABLE IF NOT EXISTS $table_name (
			id mediumint(9) NOT NULL AUTO_INCREMENT,
			status tinyint NULL,
			title tinytext NULL,
			redirect_type int NULL,
			follow_type int NULL,
			link_destination VARCHAR(200) NULL,
			date date NULL,
			cloaked_url text NULL,
			new_tab tinyint(2) NULL,
			parameters text NULL,
			created_at datetime NULL,
			updated_at datetime NULL,
			PRIMARY KEY  (id)
		) $charset_collate";
		dbDelta( $sql );
	
		$table_name = $wpdb->prefix . "dr_affiliate_geolocation"; 
		$sql = "CREATE TABLE IF NOT EXISTS $table_name (
			id mediumint(9) NOT NULL AUTO_INCREMENT,
			affiliate_id int(11) NOT NULL,
			country VARCHAR(30) NULL,
			link_destination VARCHAR(200) NULL,
			created_at datetime NULL,
			updated_at datetime NULL,
			PRIMARY KEY  (id)
		) $charset_collate";
		dbDelta( $sql );

		$table_name = $wpdb->prefix . "dr_affiliate_clicks"; 
		$sql = "CREATE TABLE IF NOT EXISTS $table_name (
			id mediumint(9) NOT NULL AUTO_INCREMENT,
			affiliate_id int(11) NOT NULL,
			ip_address VARCHAR(50) NULL,
			address VARCHAR(200) NULL,
			user_agent text NULL,
			clicked_date datetime NULL,
			PRIMARY KEY  (id)
		) $charset_collate";
		dbDelta( $sql );

		$table_name = $wpdb->prefix . "dr_affiliate_image"; 
		$sql = "CREATE TABLE IF NOT EXISTS $table_name (
			`id` mediumint(9) NOT NULL AUTO_INCREMENT,
			`affiliate_id` int(11) NOT NULL,
			`image_path` text COLLATE utf8mb4_unicode_520_ci,
			`created_at` datetime DEFAULT NULL,
			`updated_at` datetime DEFAULT NULL,
			PRIMARY KEY  (id)
		) $charset_collate";
		dbDelta( $sql );
	}

}
