<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://devrohit.com/
 * @since      1.2.2
 *
 * @package    Dr_Affilate
 * @subpackage Dr_Affilate/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Dr_Affilate
 * @subpackage Dr_Affilate/public
 * @author     Rohit Urane <rohiturane50@gmail.com>
 */
class Dr_Affilate_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.2.2
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.2.2
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.2.2
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.2.2
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Dr_Affilate_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Dr_Affilate_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/dr-affilate-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.2.2
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Dr_Affilate_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Dr_Affilate_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/dr-affilate-public.min.js', array( 'jquery' ), $this->version, false );
		/// Load constant value on front end of site
		wp_localize_script( $this->plugin_name , 'dr_affiliate_constants' , array(
			'home_url'                  => home_url(),
			'ajax_url'                  => admin_url( 'admin-ajax.php' ),
		) );
	}

	/**
	 * Get Ip Address of user
	 */
	function get_client_ip() {
		$ipaddress = '';
		if (isset($_SERVER['HTTP_CLIENT_IP']))
			$ipaddress = $_SERVER['HTTP_CLIENT_IP'];
		else if(isset($_SERVER['HTTP_X_FORWARDED_FOR']))
			$ipaddress = $_SERVER['HTTP_X_FORWARDED_FOR'];
		else if(isset($_SERVER['HTTP_X_FORWARDED']))
			$ipaddress = $_SERVER['HTTP_X_FORWARDED'];
		else if(isset($_SERVER['HTTP_FORWARDED_FOR']))
			$ipaddress = $_SERVER['HTTP_FORWARDED_FOR'];
		else if(isset($_SERVER['HTTP_FORWARDED']))
			$ipaddress = $_SERVER['HTTP_FORWARDED'];
		else if(isset($_SERVER['REMOTE_ADDR']))
			$ipaddress = $_SERVER['REMOTE_ADDR'];
		else
			$ipaddress = 'UNKNOWN';
		return $ipaddress;
	}

	/**
	 * Track Links clicked by User
	 */
	public function track_affiliate_link()
	{
		$data = $this->sanitizeTrack($_POST);
		global $wpdb;
		$options = get_option($this->plugin_name);
		$rapid = empty($options['rapid_api']) ? '': $options['rapid_api'];
		$table_name = $wpdb->prefix . "dr_affiliate"; 
		$tablename = $wpdb->prefix. "dr_affiliate_geolocation";
		$table_image = $wpdb->prefix."dr_affiliate_image";
		$body = [
			'reverse-lookup' => false, 
			'ip' => $this->get_client_ip()
		];
		$args = array(
			'body'        => $body,
			'timeout'     => '5',
			'redirection' => '5',
			'httpversion' => '1.0',
			'blocking'    => true,
			'headers'     => [
				'content-type'=> 'application/x-www-form-urlencoded',
				'x-rapidapi-key'=> $rapid,
				'x-rapidapi-host'=> 'community-neutrino-ip-info.p.rapidapi.com'
			],
			'cookies'     => array(),
		);
		if(!empty($rapid)) {
			$response = wp_remote_post( 'https://community-neutrino-ip-info.p.rapidapi.com/ip-info', $args );
			$body     = json_decode(wp_remote_retrieve_body( $response ));
		}

		$str = "SELECT id, redirect_type, follow_type, link_destination, new_tab, parameters FROM $table_name WHERE status=1 and cloaked_url like '".$data['url']."'";
		if(!empty($data['title'])) {
			$str.=" and title like '".$data['title']."'";
		}
		$link = $wpdb->get_row($str);
		if(!empty($body->country)) {
			$geoLink = $wpdb->get_row("SELECT * FROM $tablename WHERE affiliate_id=$link->id and LOWER(country) like '%".strtolower($body->country)."%'");
		}
		
		$sendData =[
			'redirect_type'=>$link->redirect_type,
			'follow_type'=>$link->follow_type,
			'link_destination'=> empty($geoLink) ? $link->link_destination : $geoLink->link_destination,
			'new_tab'=>$link->new_tab,
			'parameters'=>$link->parameters
		];
		$tablename = $wpdb->prefix."dr_affiliate_clicks";
		$insertData = [
			'affiliate_id'=>$link->id,
			'ip_address'=>$this->get_client_ip(),
			'user_agent'=>$_SERVER['HTTP_USER_AGENT'],
			'clicked_date'=>date('Y-m-d H:i:s')
		];
		$clicked = $wpdb->insert( $tablename, $insertData);
		if($clicked){
			echo json_encode(array('success' => true, 'result' =>$sendData));
		}else {
			echo json_encode(array('success' => false, 'message' =>'Something Went Wrong'));
		}
		wp_die();
	}

	/**
	 * Sanitize data 
	 */
	public function sanitizeTrack($input) 
	{
		$valid = [];
		$valid['url'] = esc_url_raw( $input['href'] );
		$valid['title'] = sanitize_text_field( $input['title'] );
		return $valid;
	}
	public function custom_redirects() 
	{
		global $wp;
		global $wpdb;
 		$current_url = home_url( $wp->request );
		$options = get_option($this->plugin_name);
		$link_prefix = empty($options['link_prefix'])? 'offers': $options['link_prefix'];
		$rapid = empty($options['rapid_api']) ? '': $options['rapid_api'];
		if(strpos($current_url, $link_prefix) !== false)
		{
			$table_name = $wpdb->prefix . "dr_affiliate"; 
			$tablename = $wpdb->prefix. "dr_affiliate_geolocation";
			$str = "SELECT id, redirect_type, follow_type, link_destination, new_tab, parameters FROM $table_name WHERE status=1 and cloaked_url like '".$current_url."'";
			$body = [
				'reverse-lookup' => false, 
				'ip' => $this->get_client_ip()
			];
			$args = array(
				'body'        => $body,
				'timeout'     => '5',
				'redirection' => '5',
				'httpversion' => '1.0',
				'blocking'    => true,
				'headers'     => [
					'content-type'=> 'application/x-www-form-urlencoded',
					'x-rapidapi-key'=> $rapid,
					'x-rapidapi-host'=> 'community-neutrino-ip-info.p.rapidapi.com'
				],
				'cookies'     => array(),
			);
			if(!empty($rapid)) {
				$response = wp_remote_post( 'https://community-neutrino-ip-info.p.rapidapi.com/ip-info', $args );
				$body     = json_decode(wp_remote_retrieve_body( $response ));
			}
			$link = $wpdb->get_row($str);
			if(!empty($body->country)) {
				$geoLink = $wpdb->get_row("SELECT * FROM $tablename WHERE affiliate_id=$link->id and LOWER(country) like '%".strtolower($body->country)."%'");
			}
			if(!empty($geoLink))
			{
				$url = $geoLink->link_destination;
				if(!empty($link->parameters)) {
					$url.='?'.$link->parameters;
				}
				wp_redirect($url, $link->redirect_type);
				exit();
			} else {
				$url = $link->link_destination;
				if(!empty($link->parameters)) {
					$url.='?'.$link->parameters;
				}
				wp_redirect($url, $link->redirect_type);
				exit();
			}
		}
		
	}
	/**
	 * Get all list affiliate Link
	 */
	public function get_affiliate_links() {
		global $wpdb;
		$table_name = $wpdb->prefix . "dr_affiliate"; 
		$links = $wpdb->get_results("SELECT * FROM $table_name WHERE status=1");
		echo json_encode(array('success' => true, 'result' =>$links));
		exit;
	}
}
