(function( $ ) {
	'use strict';

	/**
	 * All of the code for your public-facing JavaScript source
	 * should reside in this file.
	 *
	 * Note: It has been assumed you will write jQuery code here, so the
	 * $ function reference has been prepared for usage within the scope
	 * of this function.
	 *
	 * This enables you to define handlers, for when the DOM is ready:
	 *
	 * $(function() {
	 *
	 * });
	 *
	 * When the window is loaded:
	 *
	 * $( window ).load(function() {
	 *
	 * });
	 *
	 * ...and/or other possibilities.
	 *
	 * Ideally, it is not considered best practise to attach more than a
	 * single DOM-ready or window-load handler for a particular page.
	 * Although scripts in the WordPress core, Plugins and Themes may be
	 * practising this, we should strive to set a better example in our own work.
	 */
	 $(document).ready(function() {
		$('.dr_affiliate-links').click(function(e){
			jQuery.ajax({
				type: "POST",
				dataType: "json",
				//contentType: "application/json; charset=utf-8",
				url: dr_affiliate_constants.ajax_url,
				data: { 
					action: "track_links", 
					href: $(this).attr('href'), 
					title: $(this).text()
				},
				success: function(response){
					if(response.success) {
						let link = response.result;
						let url= link.link_destination;
						if(link.parameters!==null) {
							url+='?'+link.parameters;
						}
						if(link.new_tab==1){
							window.open(url, '_blank');
						} else {
							window.location.href = url;
						}
					}else {
						console.log(response.message);
					}
				}, 
				error: function(error) {
					console.log(error)
				}
			  })
			e.preventDefault();
		});
		jQuery.ajax({
			type: "POST",
			dataType: "json",
			url: dr_affiliate_constants.ajax_url,
			data: {action: "get_links"},
			success: function(msg){
				if(msg.success) {
				  localStorage.setItem('affiliate-links', JSON.stringify(msg.result));
				  let links = JSON.parse(localStorage.getItem('affiliate-links'));
				  replaceElementTag('p', '<p></p>',links);
				}
			}
		  });
	});
	function replaceElementTag(targetSelector, newTagString, links) {
		$(targetSelector).each(function() {
			let newElem
			let str = $(this).html();
			links.forEach(element => {
				if($(this).text().includes(element.title)) 
				{
					let follow='';
					if(element.follow_type==0) {
						follow = 'rel="nofollow"';
					}
					if(element.new_tab==1) {
						str = str.replace(element.title, '<a href="'+element.cloaked_url+'" class="dr_affiliate-links" target="_blank" '+follow+'>'+element.title+'</a>');
					} else {
						str = str.replace(element.title, '<a href="'+element.cloaked_url+'" class="dr_affiliate-links" '+follow+'>'+element.title+'</a>');
					}
					newElem = $(newTagString, {
						html: str
					});
				}
			});
			if(newElem == null) {
				newElem = $(newTagString, {
					html: str
				});
			}
			$(this).replaceWith(newElem);
		});
	}
})( jQuery );